@@ -20,32 +20,32 @@
 #include "mozilla/Atomics.h"
 #include "mozilla/Unused.h"
 
-using mozilla::psm::SyncRunnableBase;
 using mozilla::Atomic;
 using mozilla::Unused;
+using mozilla::psm::SyncRunnableBase;
 
 namespace {
 
 static Atomic<bool> sCertOverrideSvcExists(false);
 
-class MainThreadClearer : public SyncRunnableBase
-{
-public:
+class MainThreadClearer : public SyncRunnableBase {
+ public:
   MainThreadClearer() : mShouldClearSessionCache(false) {}
 
   void RunOnTargetThread() override {
-    // In some cases it's possible to cause PSM/NSS to initialize while XPCOM shutdown
-    // is in progress. We want to avoid this, since they do not handle the situation well,
-    // hence the flags to avoid instantiating the services if they don't already exist.
+    // In some cases it's possible to cause PSM/NSS to initialize while XPCOM
+    // shutdown is in progress. We want to avoid this, since they do not handle
+    // the situation well, hence the flags to avoid instantiating the services
+    // if they don't already exist.
 
     bool certOverrideSvcExists = sCertOverrideSvcExists.exchange(false);
     if (certOverrideSvcExists) {
       sCertOverrideSvcExists = true;
-      nsCOMPtr<nsICertOverrideService> icos = do_GetService(NS_CERTOVERRIDE_CONTRACTID);
+      nsCOMPtr<nsICertOverrideService> icos =
+          do_GetService(NS_CERTOVERRIDE_CONTRACTID);
       if (icos) {
         icos->ClearValidityOverride(
-          NS_LITERAL_CSTRING("all:temporary-certificates"),
-          0);
+            NS_LITERAL_CSTRING("all:temporary-certificates"), 0);
       }
     }
 
@@ -57,19 +57,18 @@ public:
   bool mShouldClearSessionCache;
 };
 
-} // namespace
+}  // namespace
 
 namespace mozilla {
 
-void ClearPrivateSSLState()
-{
+void ClearPrivateSSLState() {
   // This only works if it is called on the socket transport
   // service thread immediately after closing all private SSL
   // connections.
 #ifdef DEBUG
   nsresult rv;
-  nsCOMPtr<nsIEventTarget> sts
-    = do_GetService(NS_SOCKETTRANSPORTSERVICE_CONTRACTID, &rv);
+  nsCOMPtr<nsIEventTarget> sts =
+      do_GetService(NS_SOCKETTRANSPORTSERVICE_CONTRACTID, &rv);
   MOZ_ASSERT(NS_SUCCEEDED(rv));
   bool onSTSThread;
   rv = sts->IsOnCurrentThread(&onSTSThread);
@@ -79,10 +78,10 @@ void ClearPrivateSSLState()
   RefPtr<MainThreadClearer> runnable = new MainThreadClearer;
   runnable->DispatchToMainThreadAndWait();
 
-  // If NSS isn't initialized, this throws an assertion. We guard it by checking if
-  // the session cache might even have anything worth clearing.
+  // If NSS isn't initialized, this throws an assertion. We guard it by checking
+  // if the session cache might even have anything worth clearing.
   if (runnable->mShouldClearSessionCache) {
-    SSL_ClearSessionCache();
+    nsNSSComponent::DoClearSSLExternalAndInternalSessionCache();
   }
 }
 
@@ -90,27 +89,27 @@ namespace psm {
 
 namespace {
 class PrivateBrowsingObserver : public nsIObserver {
-public:
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSIOBSERVER
   explicit PrivateBrowsingObserver(SharedSSLState* aOwner) : mOwner(aOwner) {}
-protected:
-  virtual ~PrivateBrowsingObserver() {}
-private:
+
+ protected:
+  virtual ~PrivateBrowsingObserver() = default;
+
+ private:
   SharedSSLState* mOwner;
 };
 
 SharedSSLState* gPublicState;
 SharedSSLState* gPrivateState;
-} // namespace
+}  // namespace
 
 NS_IMPL_ISUPPORTS(PrivateBrowsingObserver, nsIObserver)
 
 NS_IMETHODIMP
-PrivateBrowsingObserver::Observe(nsISupports     *aSubject,
-                                 const char      *aTopic,
-                                 const char16_t *aData)
-{
+PrivateBrowsingObserver::Observe(nsISupports* aSubject, const char* aTopic,
+                                 const char16_t* aData) {
   if (!nsCRT::strcmp(aTopic, "last-pb-context-exited")) {
     mOwner->ResetStoredData();
   }
@@ -118,70 +117,49 @@ PrivateBrowsingObserver::Observe(nsISupports     *aSubject,
 }
 
 SharedSSLState::SharedSSLState(uint32_t aTlsFlags)
-: mIOLayerHelpers(aTlsFlags)
-, mMutex("SharedSSLState::mMutex")
-, mSocketCreated(false)
-, mOCSPStaplingEnabled(false)
-, mOCSPMustStapleEnabled(false)
-, mSignedCertTimestampsEnabled(false)
-{
+    : mIOLayerHelpers(aTlsFlags),
+      mMutex("SharedSSLState::mMutex"),
+      mSocketCreated(false),
+      mOCSPStaplingEnabled(false),
+      mOCSPMustStapleEnabled(false),
+      mSignedCertTimestampsEnabled(false) {
   mIOLayerHelpers.Init();
-  if (!aTlsFlags) { // the per socket flags don't need memory
-    mClientAuthRemember = new nsClientAuthRememberService();
-    mClientAuthRemember->Init();
-  }
 }
 
-SharedSSLState::~SharedSSLState()
-{
-}
+SharedSSLState::~SharedSSLState() = default;
 
-void
-SharedSSLState::NotePrivateBrowsingStatus()
-{
+void SharedSSLState::NotePrivateBrowsingStatus() {
   MOZ_ASSERT(NS_IsMainThread(), "Not on main thread");
   mObserver = new PrivateBrowsingObserver(this);
   nsCOMPtr<nsIObserverService> obsSvc = mozilla::services::GetObserverService();
   obsSvc->AddObserver(mObserver, "last-pb-context-exited", false);
 }
 
-void
-SharedSSLState::ResetStoredData()
-{
-  if (!mClientAuthRemember) {
-    return;
-  }
+void SharedSSLState::ResetStoredData() {
   MOZ_ASSERT(NS_IsMainThread(), "Not on main thread");
-  mClientAuthRemember->ClearRememberedDecisions();
   mIOLayerHelpers.clearStoredData();
 }
 
-void
-SharedSSLState::NoteSocketCreated()
-{
+void SharedSSLState::NoteSocketCreated() {
   MutexAutoLock lock(mMutex);
   mSocketCreated = true;
 }
 
-bool
-SharedSSLState::SocketCreated()
-{
+bool SharedSSLState::SocketCreated() {
   MutexAutoLock lock(mMutex);
   return mSocketCreated;
 }
 
-/*static*/ void
-SharedSSLState::GlobalInit()
-{
+/*static*/
+void SharedSSLState::GlobalInit() {
   MOZ_ASSERT(NS_IsMainThread(), "Not on main thread");
   gPublicState = new SharedSSLState();
   gPrivateState = new SharedSSLState();
   gPrivateState->NotePrivateBrowsingStatus();
 }
 
-/*static*/ void
-SharedSSLState::GlobalCleanup()
-{
+/*static*/
+void SharedSSLState::GlobalCleanup() {
   MOZ_ASSERT(NS_IsMainThread(), "Not on main thread");
 
   if (gPrivateState) {
@@ -197,29 +175,16 @@ SharedSSLState::GlobalCleanup()
   }
 }
 
-/*static*/ void
-SharedSSLState::NoteCertOverrideServiceInstantiated()
-{
+/*static*/
+void SharedSSLState::NoteCertOverrideServiceInstantiated() {
   sCertOverrideSvcExists = true;
 }
 
-void
-SharedSSLState::Cleanup()
-{
-  mIOLayerHelpers.Cleanup();
-}
+void SharedSSLState::Cleanup() { mIOLayerHelpers.Cleanup(); }
 
-SharedSSLState*
-PublicSSLState()
-{
-  return gPublicState;
-}
+SharedSSLState* PublicSSLState() { return gPublicState; }
 
-SharedSSLState*
-PrivateSSLState()
-{
-  return gPrivateState;
-}
+SharedSSLState* PrivateSSLState() { return gPrivateState; }
 
-} // namespace psm
-} // namespace mozilla
+}  // namespace psm
+}  // namespace mozilla
